utils.SimpleBitfield

|  | ## Cheshire3 Object Model: Class SimpleBitfield

Module utils :: Class SimpleBitfield

## Class SimpleBitfield
source code

Object Tree:

    object --+
             |
            SimpleBitfield

Instance Methods

__init__(self, value=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
__getitem__(self, index)
__setitem__(self, index, value)
__int__(self)
__str__(self) str(x)
__nonzero__(self)
__len__(self)
union(self, other)
intersection(self, other)
difference(self, other)
lenTrueItems(self)
trueItems(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables

Inherited from `object`: `__class__`

Method Details

### __init__(self, value=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __getitem__(self, index) (Indexing operator) | source code

### __setitem__(self, index, value) (Index assignment operator) | source code

### __int__(self) | source code

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __nonzero__(self) (Boolean test operator) | source code

### __len__(self) (Length operator) | source code

### union(self, other) | source code

### intersection(self, other) | source code

### difference(self, other) | source code

### lenTrueItems(self) | source code

### trueItems(self) | source code